<h1 align="center">cilroy</h1>

<div align="center">

kilroy controller 🎛️

[![Lint](https://github.com/kilroybot/cilroy/actions/workflows/lint.yaml/badge.svg)](https://github.com/kilroybot/cilroy/actions/workflows/lint.yaml)
[![Multiplatform tests](https://github.com/kilroybot/cilroy/actions/workflows/test-multiplatform.yaml/badge.svg)](https://github.com/kilroybot/cilroy/actions/workflows/test-multiplatform.yaml)
[![Docker tests](https://github.com/kilroybot/cilroy/actions/workflows/test-docker.yaml/badge.svg)](https://github.com/kilroybot/cilroy/actions/workflows/test-docker.yaml)
[![Docs](https://github.com/kilroybot/cilroy/actions/workflows/docs.yaml/badge.svg)](https://github.com/kilroybot/cilroy/actions/workflows/docs.yaml)

</div>

---

## Installing

Using `pip`:

```sh
pip install cilroy
```

## Usage

To run the server, install the package and run the following command:

```sh
cilroy
```

This will start the server on port 12000 by default.
Then you can communicate with the server, using any compatible client.
